EnhancedTextLayerData class

Inheritance

Constructors

EnhancedTextLayerData({required String text, Color color = Colors.white, double size = 32.0, TextAlign align = TextAlign.center, Color background = Colors.transparent, double backgroundOpacity = 0.0, Offset offsetValue = Offset.zero, double rotationValue = 0.0, String fontFamily = 'Roboto', Gradient? textGradient, Gradient? backgroundGradient, String? animation, double animationDuration = 1.0, FontWeight fontWeight = FontWeight.normal, bool isItalic = false})

Properties

align TextAlign
getter/setter pair
animation String?
getter/setter pair
animationDuration double
getter/setter pair
background Color
getter/setter pair
backgroundGradient Gradient?
getter/setter pair
backgroundOpacity double
getter/setter pair
color Color
getter/setter pair
fontFamily String
getter/setter pair
fontWeight FontWeight
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isItalic bool
getter/setter pair
offset Offset
getter/setter pairinherited
offsetValue Offset
getter/setter pair
opacity double
getter/setter pairinherited
rotation double
getter/setter pairinherited
rotationValue double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
getter/setter pairinherited
size double
getter/setter pair
text String
getter/setter pair
textGradient Gradient?
getter/setter pair

Methods

copyFrom(Map json) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited