TextAnimation enum

Available text animation types

Inheritance
Available extensions

Values

none → const TextAnimation
fade → const TextAnimation
slide → const TextAnimation
bounce → const TextAnimation
rotate → const TextAnimation
scale → const TextAnimation
pulse → const TextAnimation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on TextAnimation, provided by the TextAnimationExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TextAnimation>
A constant List of the values in this enum, in order of their declaration.