TextOption class

Constructors

TextOption({List<String> fontFamilies = const ['Roboto', 'Arial', 'Times New Roman', 'Courier', 'Georgia', 'Verdana', 'Helvetica'], List<Color> textColors = const [Colors.white, Colors.black, Colors.red, Colors.blue, Colors.green, Colors.yellow, Colors.purple, Colors.orange, Colors.pink, Colors.teal, Colors.indigo, Colors.cyan], List<Gradient> textGradients = const [LinearGradient(colors: [Colors.purple, Colors.blue], begin: Alignment.topLeft, end: Alignment.bottomRight), LinearGradient(colors: [Colors.orange, Colors.pink], begin: Alignment.topLeft, end: Alignment.bottomRight), LinearGradient(colors: [Colors.green, Colors.teal], begin: Alignment.topLeft, end: Alignment.bottomRight), LinearGradient(colors: [Colors.red, Colors.yellow], begin: Alignment.topLeft, end: Alignment.bottomRight), LinearGradient(colors: [Colors.indigo, Colors.cyan], begin: Alignment.topCenter, end: Alignment.bottomCenter)], List<Gradient> backgroundGradients = const [LinearGradient(colors: [Colors.black54, Colors.transparent], begin: Alignment.centerLeft, end: Alignment.centerRight), LinearGradient(colors: [Colors.purple, Colors.blue], begin: Alignment.topLeft, end: Alignment.bottomRight), LinearGradient(colors: [Colors.orange, Colors.pink], begin: Alignment.topLeft, end: Alignment.bottomRight), RadialGradient(colors: [Colors.yellow, Colors.red], center: Alignment.center, radius: 0.8), LinearGradient(colors: [Colors.green, Colors.teal], begin: Alignment.topLeft, end: Alignment.bottomRight)], List<TextAnimation> animations = const [TextAnimation.fade, TextAnimation.slide, TextAnimation.bounce, TextAnimation.rotate, TextAnimation.scale, TextAnimation.pulse], bool enableFontFamily = true, bool enableTextGradient = true, bool enableBackgroundGradient = true, bool enableAnimations = true})
const

Properties

animations List<TextAnimation>
Available text animations
final
backgroundGradients List<Gradient>
List of available gradient presets for text background
final
enableAnimations bool
Enable text animations
final
enableBackgroundGradient bool
Enable background gradient
final
enableFontFamily bool
Enable font family selection
final
enableTextGradient bool
Enable text gradient
final
fontFamilies List<String>
List of available font families
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColors List<Color>
List of available text colors
final
textGradients List<Gradient>
List of available gradient presets for text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited